==> curlpp-0.3.1_1.tbz: share/examples/curlpp/example05.cpp <==
/*
*    Copyright (c) <2002-2003> <Jean-Philippe Barrette-LaPierre>
*    
*    Permission is hereby granted, free of charge, to any person obtaining
*    a copy of this software and associated documentation files 
*    (curlpp), to deal in the Software without restriction, 
*    including without limitation the rights to use, copy, modify, merge,
*    publish, distribute, sublicense, and/or sell copies of the Software,
*    and to permit persons to whom the Software is furnished to do so, 
*    subject to the following conditions:
*    
*    The above copyright notice and this permission notice shall be included
*    in all copies or substantial portions of the Software.
*    
*    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
*    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
*    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
*    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
*    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
*    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#include <fstream>

#include "curlpp.hpp"

int main()
{
   try
   {
      //this initialize the curlpp library
      //if there is an exception thrown during
      //the processing curlpp will be automaticly
      //cleaned. If you check the example01.cpp
      //you will see that this behavior is not
      //present. (if an exception is thrown the
      //library is not released, and an error is
      //printed)
      curlpp::cleanup cleaner;
      
      curlpp::easy request;
      request.url( "http://www.linuxfr.org" );
      request.verbose( true );
      
      std::ofstream my_file( "./example05_body.txt" );
      curlpp::ostream_trait my_trait( &my_file );
      request.m_body_storage.trait( &my_trait, false );
      
      request.perform();
   }
   catch ( curlpp::exception & e )
   {
      std::cout << e.what() << std::endl;
      return EXIT_FAILURE;
   }
   
   
   return EXIT_SUCCESS;
}

==> curlpp-0.3.3.tbz: share/examples/curlpp/example05.cpp <==
/*
*    Copyright (c) <2002-2005> <Jean-Philippe Barrette-LaPierre>
*    
*    Permission is hereby granted, free of charge, to any person obtaining
*    a copy of this software and associated documentation files 
*    (curlpp), to deal in the Software without restriction, 
*    including without limitation the rights to use, copy, modify, merge,
*    publish, distribute, sublicense, and/or sell copies of the Software,
*    and to permit persons to whom the Software is furnished to do so, 
*    subject to the following conditions:
*    
*    The above copyright notice and this permission notice shall be included
*    in all copies or substantial portions of the Software.
*    
*    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
*    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
*    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
*    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
*    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
*    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#include <fstream>

#include <curlpp/curlpp.hpp>

int main()
{
   try
   {
      //this initialize the curlpp library
      //if there is an exception thrown during
      //the processing curlpp will be automaticly
      //cleaned. If you check the example01.cpp
      //you will see that this behavior is not
      //present. (if an exception is thrown the
      //library is not released, and an error is
      //printed)
      curlpp::cleanup cleaner;
      
      curlpp::easy request;
      request.url( "http://example.com" );
      request.verbose( true );
      
      std::ofstream my_file( "./example05_body.txt" );
      curlpp::ostream_trait my_trait( &my_file );
      request.m_body_storage.trait( &my_trait, false );
      
      request.perform();
   }
   catch ( curlpp::exception & e )
   {
      std::cout << e.what() << std::endl;
      return EXIT_FAILURE;
   }
   
   
   return EXIT_SUCCESS;
}
